JpushHarmonySdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • JpushHarmonySdkPlatform
Implementers

Constructors

JpushHarmonySdkPlatform()
Constructs a JpushHarmonySdkPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTags(int sequence, List<String> tags) → Future<Map>
checkTagBindState(int sequence, String tag) → Future<Map>
cleanTags(int sequence) → Future<Map>
clearLocalNotifications() → dynamic
clearNotification(int notificationId) → dynamic
deleteAlias(int sequence) → Future<Map>
deleteTags(int sequence, List<String> tags) → Future<Map>
getAlias(int sequence) → Future<Map>
getPushStatus() → Future<Map>
getRegistrationId() → Future<String>
getTags(int sequence, int curr) → Future<Map>
init() → dynamic
isPushStopped() → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resumePush() → dynamic
sendLocalNotification(Map<String, dynamic> notification) → Future<void>
setAlias(int sequence, String alias) → Future<Map>
setAppKey(String appKey) → dynamic
setBadgeNumber(int badgeNumber) → dynamic
setCallBack(dynamic callBack(String eventName, dynamic data)) → void
setChannel(String channel) → dynamic
setDebug(bool b) → void
setHeartbeatTime(int heartbeatTime) → dynamic
setTags(int sequence, List<String> tags) → Future<Map>
setUserRequestNotificationPermission(bool enable) → dynamic
stopPush() → dynamic
toString() → String
A string representation of this object.
inherited
turnOffPush() → Future<Map>
turnOnPush() → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ JpushHarmonySdkPlatform
The default instance of JpushHarmonySdkPlatform to use.
getter/setter pair